HareMq.AutoScaler (hare_mq v1.4.0)

A GenServer that automatically scales the number of consumers based on the number of messages in the RabbitMQ queue.

Summary

Functions

Returns a specification to start this module under a supervisor.

Functions

calculate_target_consumer_count(queue_length, config)

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(opts)